@@ -21,7 +21,7 @@
  * indicate libav
 */
 
-
+#include "translate.h"
 #include "motion.h"
 
 #ifdef HAVE_FFMPEG
@@ -67,6 +67,19 @@
 
 #endif
 
+/*********************************************/
+#if (LIBAVCODEC_VERSION_MAJOR >= 57)
+
+#define MY_CODEC_FLAG_GLOBAL_HEADER AV_CODEC_FLAG_GLOBAL_HEADER
+#define MY_CODEC_FLAG_QSCALE        AV_CODEC_FLAG_QSCALE
+
+#else
+
+#define MY_CODEC_FLAG_GLOBAL_HEADER CODEC_FLAG_GLOBAL_HEADER
+#define MY_CODEC_FLAG_QSCALE        CODEC_FLAG_QSCALE
+
+#endif
+
 /*********************************************/
 AVFrame *my_frame_alloc(void){
     AVFrame *pic;
@@ -184,7 +197,7 @@ static int ffmpeg_timelapse_exists(const char *fname){
 static int ffmpeg_timelapse_append(struct ffmpeg *ffmpeg, AVPacket pkt){
     FILE *file;
 
-    file = fopen(ffmpeg->oc->filename, "a");
+    file = fopen(ffmpeg->filename, "a");
     if (!file) return -1;
 
     fwrite(pkt.data,1,pkt.size,file);
@@ -194,6 +207,10 @@ static int ffmpeg_timelapse_append(struct ffmpeg *ffmpeg, AVPacket pkt){
     return 0;
 }
 
+#if (LIBAVFORMAT_VERSION_MAJOR < 58)
+/* TODO Determine if this is even needed for old versions. Per
+ * documentation for version 58, 'av_lockmgr_register This function does nothing'
+ */
 static int ffmpeg_lockmgr_cb(void **arg, enum AVLockOp op){
     pthread_mutex_t *mutex = *arg;
     int err;
@@ -228,6 +245,7 @@ static int ffmpeg_lockmgr_cb(void **arg, enum AVLockOp op){
     }
     return 1;
 }
+#endif
 
 static void ffmpeg_free_context(struct ffmpeg *ffmpeg){
 
@@ -254,7 +272,8 @@ static int ffmpeg_get_oformat(struct ffmpeg *ffmpeg){
     char *codec_name = malloc(codec_name_len + 1);
 
     if (codec_name == NULL) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Failed to allocate memory for codec name");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Failed to allocate memory for codec name"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
@@ -265,7 +284,9 @@ static int ffmpeg_get_oformat(struct ffmpeg *ffmpeg){
     if (((strcmp(codec_name, "msmpeg4") == 0) ||
         (strcmp(codec_name, "mpeg4") == 0) ||
         (strcmp(codec_name, "swf") == 0) ) && (ffmpeg->fps >50)){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "The frame rate specified is too high for the ffmpeg movie type specified. Choose a different ffmpeg container or lower framerate.");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("The frame rate specified is too high for the ffmpeg movie type specified. "
+            "Choose a different ffmpeg container or lower framerate."));
         ffmpeg_free_context(ffmpeg);
         free(codec_name);
         return -1;
@@ -276,7 +297,8 @@ static int ffmpeg_get_oformat(struct ffmpeg *ffmpeg){
         if (ffmpeg->oc->oformat) ffmpeg->oc->oformat->video_codec = MY_CODEC_ID_MPEG2VIDEO;
         strncat(ffmpeg->filename, ".mpg", 4);
         if (!ffmpeg->oc->oformat) {
-            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "ffmpeg_video_codec option value %s is not supported", codec_name);
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                ,_("ffmpeg_video_codec option value %s is not supported"), codec_name);
             ffmpeg_free_context(ffmpeg);
             free(codec_name);
             return -1;
@@ -338,14 +360,15 @@ static int ffmpeg_get_oformat(struct ffmpeg *ffmpeg){
 
     //Check for valid results
     if (!ffmpeg->oc->oformat) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "codec option value %s is not supported", codec_name);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("codec option value %s is not supported"), codec_name);
         ffmpeg_free_context(ffmpeg);
         free(codec_name);
         return -1;
     }
 
     if (ffmpeg->oc->oformat->video_codec == MY_CODEC_ID_NONE) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not get the codec");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not get the codec"));
         ffmpeg_free_context(ffmpeg);
         free(codec_name);
         return -1;
@@ -365,20 +388,23 @@ static int ffmpeg_encode_video(struct ffmpeg *ffmpeg){
     retcd = avcodec_send_frame(ffmpeg->ctx_codec, ffmpeg->picture);
     if (retcd < 0 ){
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error sending frame for encoding:%s",errstr);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Error sending frame for encoding:%s"),errstr);
         return -1;
     }
     retcd = avcodec_receive_packet(ffmpeg->ctx_codec, &ffmpeg->pkt);
     if (retcd == AVERROR(EAGAIN)){
         //Buffered packet.  Throw special return code
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, "Receive packet threw EAGAIN returning -2 code :%s",errstr);
+        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO
+            ,_("Receive packet threw EAGAIN returning -2 code :%s"),errstr);
         my_packet_unref(ffmpeg->pkt);
         return -2;
     }
     if (retcd < 0 ){
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error receiving encoded packet video:%s",errstr);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Error receiving encoded packet video:%s"),errstr);
         //Packet is freed upon failure of encoding
         return -1;
     }
@@ -394,7 +420,7 @@ static int ffmpeg_encode_video(struct ffmpeg *ffmpeg){
     retcd = avcodec_encode_video2(ffmpeg->ctx_codec, &ffmpeg->pkt, ffmpeg->picture, &got_packet_ptr);
     if (retcd < 0 ){
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error encoding video:%s",errstr);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Error encoding video:%s"),errstr);
         //Packet is freed upon failure of encoding
         return -1;
     }
@@ -417,7 +443,7 @@ static int ffmpeg_encode_video(struct ffmpeg *ffmpeg){
 
     retcd = avcodec_encode_video(ffmpeg->video_st->codec, video_outbuf, video_outbuf_size, ffmpeg->picture);
     if (retcd < 0 ){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error encoding video");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Error encoding video"));
         my_packet_unref(ffmpeg->pkt);
         return -1;
     }
@@ -461,16 +487,17 @@ static int ffmpeg_set_pts(struct ffmpeg *ffmpeg, const struct timeval *tv1){
         }
         ffmpeg->picture->pts = av_rescale_q(pts_interval,(AVRational){1, 1000000L},ffmpeg->video_st->time_base) + ffmpeg->base_pts;
 
-        if (ffmpeg->test_mode == 1){
-            MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "PTS %"PRId64" Base PTS %"PRId64" ms interval %"PRId64" timebase %d-%d",
-                       ffmpeg->picture->pts,ffmpeg->base_pts,pts_interval,
-                       ffmpeg->video_st->time_base.num,ffmpeg->video_st->time_base.den);
+        if (ffmpeg->test_mode == TRUE){
+            MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO
+                ,_("PTS %"PRId64" Base PTS %"PRId64" ms interval %"PRId64" timebase %d-%d")
+                ,ffmpeg->picture->pts,ffmpeg->base_pts,pts_interval
+                ,ffmpeg->video_st->time_base.num,ffmpeg->video_st->time_base.den);
         }
 
         if (ffmpeg->picture->pts <= ffmpeg->last_pts){
             //We have a problem with our motion loop timing and sending frames or the rounding into the PTS.
-            if (ffmpeg->test_mode == 1){
-                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "BAD TIMING!! Frame skipped.");
+            if (ffmpeg->test_mode == TRUE){
+                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, _("BAD TIMING!! Frame skipped."));
             }
             return -1;
         }
@@ -495,10 +522,20 @@ static int ffmpeg_set_pktpts(struct ffmpeg *ffmpeg, const struct timeval *tv1){
         }
         ffmpeg->pkt.pts = av_rescale_q(pts_interval,(AVRational){1, 1000000L},ffmpeg->video_st->time_base) + ffmpeg->base_pts;
 
+        if (ffmpeg->test_mode == TRUE){
+            MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO
+                       ,_("PTS %"PRId64" Base PTS %"PRId64" ms interval %"PRId64" timebase %d-%d Change %d")
+                       ,ffmpeg->pkt.pts
+                       ,ffmpeg->base_pts,pts_interval
+                       ,ffmpeg->video_st->time_base.num
+                       ,ffmpeg->video_st->time_base.den
+                       ,(ffmpeg->pkt.pts-ffmpeg->last_pts) );
+        }
+
         if (ffmpeg->pkt.pts <= ffmpeg->last_pts){
             //We have a problem with our motion loop timing and sending frames or the rounding into the PTS.
-            if (ffmpeg->test_mode == 1){
-                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "BAD TIMING!! Frame skipped.");
+            if (ffmpeg->test_mode == TRUE){
+                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, _("BAD TIMING!! Frame skipped."));
             }
             return -1;
         }
@@ -511,38 +548,39 @@ static int ffmpeg_set_pktpts(struct ffmpeg *ffmpeg, const struct timeval *tv1){
 static int ffmpeg_set_quality(struct ffmpeg *ffmpeg){
 
     ffmpeg->opts = 0;
-    if (ffmpeg->vbr > 100) ffmpeg->vbr = 100;
+    if (ffmpeg->quality > 100) ffmpeg->quality = 100;
     if (ffmpeg->ctx_codec->codec_id == MY_CODEC_ID_H264 ||
         ffmpeg->ctx_codec->codec_id == MY_CODEC_ID_HEVC){
-        if (ffmpeg->vbr <= 0)
-            ffmpeg->vbr = 45; // default to 45% quality
+        if (ffmpeg->quality <= 0)
+            ffmpeg->quality = 45; // default to 45% quality
         av_dict_set(&ffmpeg->opts, "preset", "ultrafast", 0);
         av_dict_set(&ffmpeg->opts, "tune", "zerolatency", 0);
         if ((strcmp(ffmpeg->codec->name, "h264_omx") == 0) || (strcmp(ffmpeg->codec->name, "mpeg4_omx") == 0)) {
             // H264 OMX encoder quality can only be controlled via bit_rate
             // bit_rate = ffmpeg->width * ffmpeg->height * ffmpeg->fps * quality_factor
-            ffmpeg->vbr = (ffmpeg->width * ffmpeg->height * ffmpeg->fps * ffmpeg->vbr) >> 7;
+            ffmpeg->quality = (ffmpeg->width * ffmpeg->height * ffmpeg->fps * ffmpeg->quality) >> 7;
             // Clip bit rate to min
-            if (ffmpeg->vbr < 4000) // magic number
-                ffmpeg->vbr = 4000;
+            if (ffmpeg->quality < 4000) // magic number
+                ffmpeg->quality = 4000;
             ffmpeg->ctx_codec->profile = FF_PROFILE_H264_HIGH;
-            ffmpeg->ctx_codec->bit_rate = ffmpeg->vbr;
+            ffmpeg->ctx_codec->bit_rate = ffmpeg->quality;
         } else {
             // Control other H264 encoders quality via CRF
             char crf[10];
-            ffmpeg->vbr = (int)(( (100-ffmpeg->vbr) * 51)/100);
-            snprintf(crf, 10, "%d", ffmpeg->vbr);
+            ffmpeg->quality = (int)(( (100-ffmpeg->quality) * 51)/100);
+            snprintf(crf, 10, "%d", ffmpeg->quality);
             av_dict_set(&ffmpeg->opts, "crf", crf, 0);
         }
     } else {
-        /* The selection of 8000 in the else is a subjective number based upon viewing output files */
-        if (ffmpeg->vbr > 0){
-            ffmpeg->vbr =(int)(((100-ffmpeg->vbr)*(100-ffmpeg->vbr)*(100-ffmpeg->vbr) * 8000) / 1000000) + 1;
-            ffmpeg->ctx_codec->flags |= CODEC_FLAG_QSCALE;
-            ffmpeg->ctx_codec->global_quality=ffmpeg->vbr;
+        /* The selection of 8000 is a subjective number based upon viewing output files */
+        if (ffmpeg->quality > 0){
+            ffmpeg->quality =(int)(((100-ffmpeg->quality)*(100-ffmpeg->quality)*(100-ffmpeg->quality) * 8000) / 1000000) + 1;
+            ffmpeg->ctx_codec->flags |= MY_CODEC_FLAG_QSCALE;
+            ffmpeg->ctx_codec->global_quality=ffmpeg->quality;
         }
     }
-    MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "%s codec vbr/crf/bit_rate: %d", ffmpeg->codec->name, ffmpeg->vbr);
+    MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO
+        ,_("%s codec vbr/crf/bit_rate: %d"), ffmpeg->codec->name, ffmpeg->quality);
 
     return 0;
 }
@@ -578,43 +616,49 @@ static int ffmpeg_set_codec(struct ffmpeg *ffmpeg){
     ffmpeg->codec = NULL;
     if (ffmpeg->codec_name[codec_name_len]) {
         if (ffmpeg_codec_is_blacklisted(&ffmpeg->codec_name[codec_name_len+1])) {
-            MOTION_LOG(WRN, TYPE_ENCODER, NO_ERRNO, "Preferred codec %s has been blacklisted",
-                       &ffmpeg->codec_name[codec_name_len+1]);
+            MOTION_LOG(WRN, TYPE_ENCODER, NO_ERRNO
+                ,_("Preferred codec %s has been blacklisted")
+                ,&ffmpeg->codec_name[codec_name_len+1]);
         } else {
             ffmpeg->codec = avcodec_find_encoder_by_name(&ffmpeg->codec_name[codec_name_len+1]);
-            if (!ffmpeg->codec)
-                MOTION_LOG(WRN, TYPE_ENCODER, NO_ERRNO, "Preferred codec %s not found",
-                           &ffmpeg->codec_name[codec_name_len+1]);
+            if ((ffmpeg->oc->oformat) && (ffmpeg->codec != NULL)) {
+                    ffmpeg->oc->oformat->video_codec = ffmpeg->codec->id;
+            } else if (ffmpeg->codec == NULL) {
+                MOTION_LOG(WRN, TYPE_ENCODER, NO_ERRNO
+                    ,_("Preferred codec %s not found")
+                    ,&ffmpeg->codec_name[codec_name_len+1]);
+            }
         }
     }
     if (!ffmpeg->codec)
         ffmpeg->codec = avcodec_find_encoder(ffmpeg->oc->oformat->video_codec);
     if (!ffmpeg->codec) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Codec %s not found", ffmpeg->codec_name);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Codec %s not found"), ffmpeg->codec_name);
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
     if (ffmpeg->codec_name[codec_name_len])
-        MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, "Using codec %s", ffmpeg->codec->name);
+        MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO,_("Using codec %s"), ffmpeg->codec->name);
 
 #if (LIBAVFORMAT_VERSION_MAJOR >= 58) || ((LIBAVFORMAT_VERSION_MAJOR == 57) && (LIBAVFORMAT_VERSION_MINOR >= 41))
     //If we provide the codec to this, it results in a memory leak.  ffmpeg ticket: 5714
     ffmpeg->video_st = avformat_new_stream(ffmpeg->oc, NULL);
     if (!ffmpeg->video_st) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not alloc stream");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not alloc stream"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
     ffmpeg->ctx_codec = avcodec_alloc_context3(ffmpeg->codec);
     if (ffmpeg->ctx_codec == NULL) {
-        MOTION_LOG(ERR, TYPE_NETCAM, NO_ERRNO, "Failed to allocate decoder!");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Failed to allocate decoder!"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
 #else
     ffmpeg->video_st = avformat_new_stream(ffmpeg->oc, ffmpeg->codec);
     if (!ffmpeg->video_st) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not alloc stream");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not alloc stream"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
@@ -632,6 +676,7 @@ static int ffmpeg_set_codec(struct ffmpeg *ffmpeg){
         } else {
             ffmpeg->ctx_codec->gop_size = (ffmpeg->fps / 2);
         }
+        ffmpeg->gop_cnt = ffmpeg->ctx_codec->gop_size - 1;
     }
 
     /*  For certain containers, setting the fps to very low numbers results in
@@ -663,11 +708,11 @@ static int ffmpeg_set_codec(struct ffmpeg *ffmpeg){
       ffmpeg->ctx_codec->strict_std_compliance = -2;
       ffmpeg->ctx_codec->level = 3;
     }
-    ffmpeg->ctx_codec->flags |= CODEC_FLAG_GLOBAL_HEADER;
+    ffmpeg->ctx_codec->flags |= MY_CODEC_FLAG_GLOBAL_HEADER;
 
     retcd = ffmpeg_set_quality(ffmpeg);
     if (retcd < 0){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Unable to set quality");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Unable to set quality"));
         return -1;
     }
 
@@ -676,7 +721,8 @@ static int ffmpeg_set_codec(struct ffmpeg *ffmpeg){
         if (ffmpeg->codec->supported_framerates) {
             const AVRational *fps = ffmpeg->codec->supported_framerates;
             while (fps->num) {
-                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "Reported FPS Supported %d/%d", fps->num, fps->den);
+                MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO
+                    ,_("Reported FPS Supported %d/%d"), fps->num, fps->den);
                 fps++;
             }
         }
@@ -688,7 +734,7 @@ static int ffmpeg_set_codec(struct ffmpeg *ffmpeg){
         }
         if (retcd < 0){
             av_strerror(retcd, errstr, sizeof(errstr));
-            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not open codec %s",errstr);
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not open codec %s"),errstr);
             av_dict_free(&ffmpeg->opts);
             ffmpeg_free_context(ffmpeg);
             return -1;
@@ -709,7 +755,8 @@ static int ffmpeg_set_stream(struct ffmpeg *ffmpeg){
     retcd = avcodec_parameters_from_context(ffmpeg->video_st->codecpar,ffmpeg->ctx_codec);
     if (retcd < 0) {
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Failed to copy decoder parameters!: %s", errstr);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Failed to copy decoder parameters!: %s"), errstr);
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
@@ -725,14 +772,14 @@ static int ffmpeg_set_picture(struct ffmpeg *ffmpeg){
 
     ffmpeg->picture = my_frame_alloc();
     if (!ffmpeg->picture) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "could not alloc frame");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("could not alloc frame"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
 
     /* Take care of variable bitrate setting. */
-    if (ffmpeg->vbr)
-        ffmpeg->picture->quality = ffmpeg->vbr;
+    if (ffmpeg->quality)
+        ffmpeg->picture->quality = ffmpeg->quality;
 
     ffmpeg->picture->linesize[0] = ffmpeg->ctx_codec->width;
     ffmpeg->picture->linesize[1] = ffmpeg->ctx_codec->width / 2;
@@ -751,7 +798,10 @@ static int ffmpeg_set_outputfile(struct ffmpeg *ffmpeg){
     int retcd;
     char errstr[128];
 
+#if (LIBAVFORMAT_VERSION_MAJOR < 58)
     snprintf(ffmpeg->oc->filename, sizeof(ffmpeg->oc->filename), "%s", ffmpeg->filename);
+#endif
+
     /* Open the output file, if needed. */
     if ((ffmpeg_timelapse_exists(ffmpeg->filename) == 0) || (ffmpeg->tlapse != TIMELAPSE_APPEND)) {
         if (!(ffmpeg->oc->oformat->flags & AVFMT_NOFILE)) {
@@ -762,17 +812,20 @@ static int ffmpeg_set_outputfile(struct ffmpeg *ffmpeg){
                         return -1;
                     }
                     if (avio_open(&ffmpeg->oc->pb, ffmpeg->filename, MY_FLAG_WRITE) < 0) {
-                        MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO, "error opening file %s", ffmpeg->filename);
+                        MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO
+                            ,_("error opening file %s"), ffmpeg->filename);
                         ffmpeg_free_context(ffmpeg);
                         return -1;
                     }
                     /* Permission denied */
                 } else if (errno ==  EACCES) {
-                    MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO, "Permission denied. %s",ffmpeg->filename);
+                    MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO
+                        ,_("Permission denied. %s"),ffmpeg->filename);
                     ffmpeg_free_context(ffmpeg);
                     return -1;
                 } else {
-                    MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO, "Error opening file %s", ffmpeg->filename);
+                    MOTION_LOG(ERR, TYPE_ENCODER, SHOW_ERRNO
+                        ,_("Error opening file %s"), ffmpeg->filename);
                     ffmpeg_free_context(ffmpeg);
                     return -1;
                 }
@@ -786,7 +839,8 @@ static int ffmpeg_set_outputfile(struct ffmpeg *ffmpeg){
         retcd = avformat_write_header(ffmpeg->oc, NULL);
         if (retcd < 0){
             av_strerror(retcd, errstr, sizeof(errstr));
-            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not write ffmpeg header %s",errstr);
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                ,_("Could not write ffmpeg header %s"),errstr);
             ffmpeg_free_context(ffmpeg);
             return -1;
         }
@@ -805,17 +859,23 @@ static int ffmpeg_flush_codec(struct ffmpeg *ffmpeg){
 
 #if (LIBAVFORMAT_VERSION_MAJOR >= 58) || ((LIBAVFORMAT_VERSION_MAJOR == 57) && (LIBAVFORMAT_VERSION_MINOR >= 41))
     //ffmpeg version 3.1 and after
+
     int retcd;
     int recv_cd = 0;
     char errstr[128];
 
+    if (ffmpeg->passthrough){
+        return 0;
+    }
+
     retcd = 0;
     recv_cd = 0;
     if (ffmpeg->tlapse == TIMELAPSE_NONE) {
         retcd = avcodec_send_frame(ffmpeg->ctx_codec, NULL);
         if (retcd < 0 ){
             av_strerror(retcd, errstr, sizeof(errstr));
-            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error entering draining mode:%s",errstr);
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                ,_("Error entering draining mode:%s"),errstr);
             return -1;
         }
         while (recv_cd != AVERROR_EOF){
@@ -826,13 +886,15 @@ static int ffmpeg_flush_codec(struct ffmpeg *ffmpeg){
             if (recv_cd != AVERROR_EOF){
                 if (recv_cd < 0){
                     av_strerror(recv_cd, errstr, sizeof(errstr));
-                    MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error draining codec:%s",errstr);
+                    MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                        ,_("Error draining codec:%s"),errstr);
                     my_packet_unref(ffmpeg->pkt);
                     return -1;
                 }
                 retcd = av_write_frame(ffmpeg->oc, &ffmpeg->pkt);
                 if (retcd < 0) {
-                    MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error writing draining video frame");
+                    MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                        ,_("Error writing draining video frame"));
                     return -1;
                 }
             }
@@ -867,7 +929,9 @@ static int ffmpeg_put_frame(struct ffmpeg *ffmpeg, const struct timeval *tv1){
 
     retcd = ffmpeg_encode_video(ffmpeg);
     if (retcd != 0){
-        if (retcd != -2) MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error while encoding picture");
+        if (retcd != -2){
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Error while encoding picture"));
+        }
         my_packet_unref(ffmpeg->pkt);
         return retcd;
     }
@@ -880,48 +944,216 @@ static int ffmpeg_put_frame(struct ffmpeg *ffmpeg, const struct timeval *tv1){
     my_packet_unref(ffmpeg->pkt);
 
     if (retcd < 0) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error while writing video frame");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Error while writing video frame"));
         return -1;
     }
     return retcd;
 
 }
 
-static int ffmpeg_put_passthrough(struct ffmpeg *ffmpeg, const struct timeval *tv1, struct image_data *img_data){
-    int retcd;
+static void ffmpeg_passthru_reset(struct ffmpeg *ffmpeg){
+    /* Reset the written flag at start of each event */
+    int indx;
+
+    pthread_mutex_lock(&ffmpeg->rtsp_data->mutex_pktarray);
+        for(indx = 0; indx < ffmpeg->rtsp_data->pktarray_size; indx++) {
+            ffmpeg->rtsp_data->pktarray[indx].iswritten = FALSE;
+        }
+    pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_pktarray);
+
+}
+
+static void ffmpeg_passthru_write(struct ffmpeg *ffmpeg, int indx){
+    /* Write the packet in the buffer at indx to file */
     char errstr[128];
+    int retcd;
 
     av_init_packet(&ffmpeg->pkt);
     ffmpeg->pkt.data = NULL;
     ffmpeg->pkt.size = 0;
 
-    if (ffmpeg->high_resolution){
-        retcd = my_copy_packet(&ffmpeg->pkt, &img_data->packet_high);
-    } else {
-        retcd = my_copy_packet(&ffmpeg->pkt, &img_data->packet_norm);
-    }
 
+    ffmpeg->rtsp_data->pktarray[indx].iswritten = TRUE;
+
+    retcd = my_copy_packet(&ffmpeg->pkt, &ffmpeg->rtsp_data->pktarray[indx].packet);
     if (retcd < 0) {
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO, "av_copy_packet: %s",errstr);
-        my_packet_unref(img_data->packet_norm);
+        MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "av_copy_packet: %s",errstr);
+        my_packet_unref(ffmpeg->pkt);
+        return;
     }
 
-    retcd = ffmpeg_set_pktpts(ffmpeg, tv1);
+    retcd = ffmpeg_set_pktpts(ffmpeg, &ffmpeg->rtsp_data->pktarray[indx].timestamp_tv);
     if (retcd < 0) {
-        //If there is an error, it has already been reported.
         my_packet_unref(ffmpeg->pkt);
-        return 0;
+        return;
     }
 
+    ffmpeg->pkt.stream_index = 0;
+
     retcd = av_write_frame(ffmpeg->oc, &ffmpeg->pkt);
     my_packet_unref(ffmpeg->pkt);
     if (retcd < 0) {
         av_strerror(retcd, errstr, sizeof(errstr));
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error while writing video frame: %s",errstr);
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+            ,_("Error while writing video frame: %s"),errstr);
+        return;
+    }
+
+}
+
+static int ffmpeg_passthru_put(struct ffmpeg *ffmpeg, struct image_data *img_data){
+
+    int idnbr_image, idnbr_lastwritten, idnbr_stop, idnbr_firstkey;
+    int indx, indx_lastwritten, indx_firstkey;
+
+    if (ffmpeg->rtsp_data == NULL) return -1;
+
+    if ((ffmpeg->rtsp_data->status == RTSP_NOTCONNECTED  ) ||
+        (ffmpeg->rtsp_data->status == RTSP_RECONNECTING  ) ){
+        return 0;
+    }
+
+    if (ffmpeg->high_resolution){
+        idnbr_image = img_data->idnbr_high;
+    } else {
+        idnbr_image = img_data->idnbr_norm;
+    }
+
+    pthread_mutex_lock(&ffmpeg->rtsp_data->mutex_pktarray);
+        idnbr_lastwritten = 0;
+        idnbr_firstkey = idnbr_image;
+        idnbr_stop = 0;
+        indx_lastwritten = -1;
+        indx_firstkey = -1;
+
+        for(indx = 0; indx < ffmpeg->rtsp_data->pktarray_size; indx++) {
+            if ((ffmpeg->rtsp_data->pktarray[indx].iswritten) &&
+                (ffmpeg->rtsp_data->pktarray[indx].idnbr > idnbr_lastwritten)){
+                idnbr_lastwritten=ffmpeg->rtsp_data->pktarray[indx].idnbr;
+                indx_lastwritten = indx;
+            }
+            if ((ffmpeg->rtsp_data->pktarray[indx].idnbr >  idnbr_stop) &&
+                (ffmpeg->rtsp_data->pktarray[indx].idnbr <= idnbr_image)){
+                idnbr_stop=ffmpeg->rtsp_data->pktarray[indx].idnbr;
+            }
+            if ((ffmpeg->rtsp_data->pktarray[indx].iskey) &&
+                (ffmpeg->rtsp_data->pktarray[indx].idnbr <= idnbr_firstkey)){
+                    idnbr_firstkey=ffmpeg->rtsp_data->pktarray[indx].idnbr;
+                    indx_firstkey = indx;
+            }
+        }
+
+        if (idnbr_stop == 0){
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_pktarray);
+            return 0;
+        }
+
+        if (indx_lastwritten != -1){
+            indx = indx_lastwritten;
+        } else if (indx_firstkey != -1) {
+            indx = indx_firstkey;
+        } else {
+            indx = 0;
+        }
+
+        while (TRUE){
+            if ((!ffmpeg->rtsp_data->pktarray[indx].iswritten) &&
+                (ffmpeg->rtsp_data->pktarray[indx].packet.size > 0) &&
+                (ffmpeg->rtsp_data->pktarray[indx].idnbr >  idnbr_lastwritten) &&
+                (ffmpeg->rtsp_data->pktarray[indx].idnbr <= idnbr_image)) {
+                ffmpeg_passthru_write(ffmpeg, indx);
+            }
+            if (ffmpeg->rtsp_data->pktarray[indx].idnbr == idnbr_stop) break;
+            indx++;
+            if (indx == ffmpeg->rtsp_data->pktarray_size ) indx = 0;
+        }
+    pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_pktarray);
+    return 0;
+}
+
+static int ffmpeg_passthru_codec(struct ffmpeg *ffmpeg){
+
+    int retcd;
+    AVStream    *stream_in;
+
+    if (ffmpeg->rtsp_data == NULL){
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("RTSP context not available."));
         return -1;
     }
-    return retcd;
+
+    pthread_mutex_lock(&ffmpeg->rtsp_data->mutex_transfer);
+
+        if ((ffmpeg->rtsp_data->status == RTSP_NOTCONNECTED  ) ||
+            (ffmpeg->rtsp_data->status == RTSP_RECONNECTING  ) ){
+            MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO
+                ,_("rtsp camera not ready for pass-through."));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+
+        if (strcmp(ffmpeg->codec_name, "mp4") != 0){
+            MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO
+                ,_("pass-through mode enabled.  Changing to MP4 container."));
+            ffmpeg->codec_name = "mp4";
+        }
+
+        retcd = ffmpeg_get_oformat(ffmpeg);
+        if (retcd < 0 ) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not get codec!"));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+
+#if (LIBAVFORMAT_VERSION_MAJOR >= 58) || ((LIBAVFORMAT_VERSION_MAJOR == 57) && (LIBAVFORMAT_VERSION_MINOR >= 41))
+        stream_in = ffmpeg->rtsp_data->transfer_format->streams[0];
+        ffmpeg->oc->oformat->video_codec = stream_in->codecpar->codec_id;
+
+        ffmpeg->video_st = avformat_new_stream(ffmpeg->oc, NULL);
+        if (!ffmpeg->video_st) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not alloc stream"));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+
+        retcd = avcodec_parameters_copy(ffmpeg->video_st->codecpar, stream_in->codecpar);
+        if (retcd < 0){
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Unable to copy codec parameters"));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+        ffmpeg->video_st->codecpar->codec_tag  = 0;
+
+#elif (LIBAVFORMAT_VERSION_MAJOR >= 55)
+
+        stream_in = ffmpeg->rtsp_data->transfer_format->streams[0];
+
+        ffmpeg->video_st = avformat_new_stream(ffmpeg->oc, stream_in->codec->codec);
+        if (!ffmpeg->video_st) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not alloc stream"));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+
+        retcd = avcodec_copy_context(ffmpeg->video_st->codec, stream_in->codec);
+        if (retcd < 0){
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Unable to copy codec parameters"));
+            pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+            return -1;
+        }
+        ffmpeg->video_st->codec->flags     |= MY_CODEC_FLAG_GLOBAL_HEADER;
+        ffmpeg->video_st->codec->codec_tag  = 0;
+#else
+        /* This is disabled in the util_check_passthrough but we need it here for compiling */
+        pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+        MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, _("Pass-through disabled.  ffmpeg too old"));
+        return -1;
+#endif
+
+        ffmpeg->video_st->time_base         = stream_in->time_base;
+    pthread_mutex_unlock(&ffmpeg->rtsp_data->mutex_transfer);
+    MOTION_LOG(INF, TYPE_ENCODER, NO_ERRNO, "Pass-through stream opened");
+    return 0;
 
 }
 
@@ -958,30 +1190,39 @@ void ffmpeg_avcodec_log(void *ignoreme ATTRIBUTE_UNUSED, int errno_flag ATTRIBUT
 
 void ffmpeg_global_init(void){
 #ifdef HAVE_FFMPEG
-    int ret;
 
-    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO,
-        "ffmpeg libavcodec version %d.%d.%d"
-        " libavformat version %d.%d.%d"
+
+    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO
+        ,_("ffmpeg libavcodec version %d.%d.%d"
+        " libavformat version %d.%d.%d")
         , LIBAVCODEC_VERSION_MAJOR, LIBAVCODEC_VERSION_MINOR, LIBAVCODEC_VERSION_MICRO
         , LIBAVFORMAT_VERSION_MAJOR, LIBAVFORMAT_VERSION_MINOR, LIBAVFORMAT_VERSION_MICRO);
 
+#if (LIBAVFORMAT_VERSION_MAJOR < 58)
+    /* TODO: Determine if this is even needed for older versions */
     av_register_all();
     avcodec_register_all();
+#endif
+
+
     avformat_network_init();
     avdevice_register_all();
     av_log_set_callback((void *)ffmpeg_avcodec_log);
 
+#if (LIBAVFORMAT_VERSION_MAJOR < 58)
+    /* TODO: Determine if this is even needed for older versions */
+    int ret;
     ret = av_lockmgr_register(ffmpeg_lockmgr_cb);
     if (ret < 0)
     {
-        MOTION_LOG(EMG, TYPE_ALL, SHOW_ERRNO, "av_lockmgr_register failed (%d)", ret);
+        MOTION_LOG(EMG, TYPE_ALL, SHOW_ERRNO, _("av_lockmgr_register failed (%d)"), ret);
         exit(1);
     }
+#endif
 
 #else /* No FFMPEG */
 
-    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, "No ffmpeg functionality included");
+    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, _("No ffmpeg functionality included"));
 
 #endif /* HAVE_FFMPEG */
 }
@@ -990,15 +1231,20 @@ void ffmpeg_global_deinit(void) {
 #ifdef HAVE_FFMPEG
 
     avformat_network_deinit();
+
+#if (LIBAVFORMAT_VERSION_MAJOR < 58)
+    /* TODO Determine if this is even needed for old versions */
     if (av_lockmgr_register(NULL) < 0)
     {
-        MOTION_LOG(EMG, TYPE_ALL, SHOW_ERRNO, "av_lockmgr_register reset failed on cleanup");
+        MOTION_LOG(EMG, TYPE_ALL, SHOW_ERRNO
+            ,_("av_lockmgr_register reset failed on cleanup"));
     }
+#endif
 
 
 #else /* No FFMPEG */
 
-    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, "No ffmpeg functionality included");
+    MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, _("No ffmpeg functionality included"));
 
 #endif /* HAVE_FFMPEG */
 }
@@ -1011,39 +1257,53 @@ int ffmpeg_open(struct ffmpeg *ffmpeg){
 
     ffmpeg->oc = avformat_alloc_context();
     if (!ffmpeg->oc) {
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not allocate output context");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not allocate output context"));
         ffmpeg_free_context(ffmpeg);
         return -1;
     }
 
-    retcd = ffmpeg_get_oformat(ffmpeg);
-    if (retcd < 0 ) {
-        MOTION_LOG(ERR, TYPE_NETCAM, NO_ERRNO, "Could not get codec!");
-        ffmpeg_free_context(ffmpeg);
-        return -1;
+    if (ffmpeg->passthrough) {
+        retcd = ffmpeg_passthru_codec(ffmpeg);
+        if (retcd < 0 ) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not setup passthru!"));
+            ffmpeg_free_context(ffmpeg);
+            return -1;
+        }
+
+        ffmpeg_passthru_reset(ffmpeg);
+
+    } else {
+        retcd = ffmpeg_get_oformat(ffmpeg);
+        if (retcd < 0 ) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not get codec!"));
+            ffmpeg_free_context(ffmpeg);
+            return -1;
+        }
+
+        retcd = ffmpeg_set_codec(ffmpeg);
+        if (retcd < 0 ) {
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Failed to allocate codec!"));
+            return -1;
+        }
+
+        retcd = ffmpeg_set_stream(ffmpeg);
+        if (retcd < 0){
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not set the stream"));
+            return -1;
+        }
+
+        retcd = ffmpeg_set_picture(ffmpeg);
+        if (retcd < 0){
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not set the stream"));
+            return -1;
+        }
     }
 
-    retcd = ffmpeg_set_codec(ffmpeg);
-    if (retcd < 0 ) {
-        MOTION_LOG(ERR, TYPE_NETCAM, NO_ERRNO, "Failed to allocate codec!");
-        return -1;
-    }
 
-    retcd = ffmpeg_set_stream(ffmpeg);
-    if (retcd < 0){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not set the stream");
-        return -1;
-    }
-
-    retcd = ffmpeg_set_picture(ffmpeg);
-    if (retcd < 0){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not set the stream");
-        return -1;
-    }
 
     retcd = ffmpeg_set_outputfile(ffmpeg);
     if (retcd < 0){
-        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Could not set the stream");
+        MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Could not set the stream"));
         return -1;
     }
 
@@ -1052,7 +1312,7 @@ int ffmpeg_open(struct ffmpeg *ffmpeg){
 #else /* No FFMPEG */
 
     if (ffmpeg) {
-        MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, "No ffmpeg functionality included");
+        MOTION_LOG(NTC, TYPE_ENCODER, NO_ERRNO, _("No ffmpeg functionality included"));
     }
     return -1;
 
@@ -1066,15 +1326,16 @@ void ffmpeg_close(struct ffmpeg *ffmpeg){
     if (ffmpeg != NULL) {
 
         if (ffmpeg_flush_codec(ffmpeg) < 0){
-            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Error flushing codec");
+            MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, _("Error flushing codec"));
         }
-
-        if (ffmpeg->tlapse != TIMELAPSE_APPEND) {
-            av_write_trailer(ffmpeg->oc);
-        }
-        if (!(ffmpeg->oc->oformat->flags & AVFMT_NOFILE)) {
+        if (ffmpeg->oc->pb != NULL){
             if (ffmpeg->tlapse != TIMELAPSE_APPEND) {
-                avio_close(ffmpeg->oc->pb);
+                av_write_trailer(ffmpeg->oc);
+            }
+            if (!(ffmpeg->oc->oformat->flags & AVFMT_NOFILE)) {
+                if (ffmpeg->tlapse != TIMELAPSE_APPEND) {
+                    avio_close(ffmpeg->oc->pb);
+                }
             }
         }
         ffmpeg_free_context(ffmpeg);
@@ -1092,7 +1353,7 @@ int ffmpeg_put_image(struct ffmpeg *ffmpeg, struct image_data *img_data, const s
     unsigned char *image;
 
     if (ffmpeg->passthrough) {
-        retcd = ffmpeg_put_passthrough(ffmpeg, tv1, img_data);
+        retcd = ffmpeg_passthru_put(ffmpeg, img_data);
         return retcd;
     }
 
@@ -1128,14 +1389,15 @@ int ffmpeg_put_image(struct ffmpeg *ffmpeg, struct image_data *img_data, const s
             retcd = ffmpeg_put_frame(ffmpeg, tv1);
             cnt++;
             if (cnt > 50){
-                MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO, "Excessive attempts to clear buffered packet");
+                MOTION_LOG(ERR, TYPE_ENCODER, NO_ERRNO
+                    ,_("Excessive attempts to clear buffered packet"));
                 retcd = -1;
             }
         }
         //non timelapse buffered is ok
         if (retcd == -2){
             retcd = 0;
-            MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, "Buffered packet");
+            MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, _("Buffered packet"));
         }
     }
 
@@ -1143,7 +1405,7 @@ int ffmpeg_put_image(struct ffmpeg *ffmpeg, struct image_data *img_data, const s
 
 #else
     if (ffmpeg && img_data && tv1) {
-        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, "No ffmpeg support");
+        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, _("No ffmpeg support"));
     }
     return 0;
 #endif // HAVE_FFMPEG
@@ -1161,7 +1423,7 @@ void ffmpeg_reset_movie_start_time(struct ffmpeg *ffmpeg, const struct timeval *
 
 #else
     if (ffmpeg && tv1) {
-        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, "No ffmpeg support");
+        MOTION_LOG(DBG, TYPE_ENCODER, NO_ERRNO, _("No ffmpeg support"));
     }
 #endif // HAVE_FFMPEG
 }
