@@ -12,7 +12,7 @@
 #define __JPEGUTILS_H__
 
 int jpgutl_decode_jpeg (unsigned char *jpeg_data_in, int jpeg_data_len,
-                     unsigned int width, unsigned int height, unsigned char *img_out);
+                     unsigned int width, unsigned int height, unsigned char *volatile img_out);
 
 
 #endif
