@@ -21,6 +21,7 @@
 #include "interface/mmal/util/mmal_connection.h"
 #include "raspicam/RaspiCamControl.h"
 
+#include "translate.h"
 #include "motion.h"
 #include "rotate.h"
 
@@ -63,8 +64,8 @@ static void check_disable_port(MMAL_PORT_T *port)
 static void camera_control_callback(MMAL_PORT_T *port, MMAL_BUFFER_HEADER_T *buffer)
 {
     if (buffer->cmd != MMAL_EVENT_PARAMETER_CHANGED) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Received unexpected camera control callback event, 0x%08x",
-                buffer->cmd);
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+            ,_("Received unexpected camera control callback event, 0x%08x"), buffer->cmd);
     }
 
     mmal_buffer_header_release(buffer);
@@ -93,6 +94,11 @@ static void set_video_port_format(mmalcam_context_ptr mmalcam, MMAL_ES_FORMAT_T
     set_port_format(mmalcam, format);
     format->es->video.frame_rate.num = mmalcam->framerate;
     format->es->video.frame_rate.den = VIDEO_FRAME_RATE_DEN;
+    if (mmalcam->framerate > 30){
+        /* The pi noir camera could not determine autoexpose at high frame rates */
+        MOTION_LOG(WRN, TYPE_VIDEO, NO_ERRNO, _("A high frame rate can cause problems with exposure of images"));
+        MOTION_LOG(WRN, TYPE_VIDEO, NO_ERRNO, _("If autoexposure is not working, try a lower frame rate."));
+    }
 }
 
 static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmalcam_name)
@@ -104,12 +110,14 @@ static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmal
     status = mmal_component_create(mmalcam_name, &camera_component);
 
     if (status != MMAL_SUCCESS) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Failed to create MMAL camera component %s", mmalcam_name);
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+            ,_("Failed to create MMAL camera component %s"), mmalcam_name);
         goto error;
     }
 
     if (camera_component->output_num == 0) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "MMAL camera %s doesn't have output ports", mmalcam_name);
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+            ,_("MMAL camera %s doesn't have output ports"), mmalcam_name);
         goto error;
     }
 
@@ -118,7 +126,8 @@ static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmal
     status = mmal_port_enable(camera_component->control, camera_control_callback);
 
     if (status) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Unable to enable control port : error %d", status);
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+            ,_("Unable to enable control port : error %d"), status);
         goto error;
     }
 
@@ -147,13 +156,13 @@ static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmal
 
     if (mmal_port_parameter_set_boolean(video_port, MMAL_PARAMETER_NO_IMAGE_PADDING, 1)
             != MMAL_SUCCESS) {
-        MOTION_LOG(WRN, TYPE_VIDEO, NO_ERRNO, "MMAL no-padding setup failed");
+        MOTION_LOG(WRN, TYPE_VIDEO, NO_ERRNO, _("MMAL no-padding setup failed"));
     }
 
     status = mmal_port_format_commit(video_port);
 
     if (status) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "camera video format couldn't be set");
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("camera video format couldn't be set"));
         goto error;
     }
 
@@ -165,7 +174,7 @@ static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmal
     status = mmal_component_enable(camera_component);
 
     if (status) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "camera component couldn't be enabled");
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("camera component couldn't be enabled"));
         goto error;
     }
 
@@ -173,7 +182,7 @@ static int create_camera_component(mmalcam_context_ptr mmalcam, const char *mmal
     mmalcam->camera_component = camera_component;
     mmalcam->camera_capture_port = video_port;
     mmalcam->camera_capture_port->userdata = (struct MMAL_PORT_USERDATA_T*) mmalcam;
-    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO, "MMAL camera component created");
+    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO, _("MMAL camera component created"));
     return MMALCAM_OK;
 
     error: if (mmalcam->camera_component != NULL ) {
@@ -197,13 +206,13 @@ static int create_camera_buffer_structures(mmalcam_context_ptr mmalcam)
     mmalcam->camera_buffer_pool = mmal_pool_create(mmalcam->camera_capture_port->buffer_num,
             mmalcam->camera_capture_port->buffer_size);
     if (mmalcam->camera_buffer_pool == NULL ) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "MMAL camera buffer pool creation failed");
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("MMAL camera buffer pool creation failed"));
         return MMALCAM_ERROR;
     }
 
     mmalcam->camera_buffer_queue = mmal_queue_create();
     if (mmalcam->camera_buffer_queue == NULL ) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "MMAL camera buffer queue creation failed");
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("MMAL camera buffer queue creation failed"));
         return MMALCAM_ERROR;
     }
 
@@ -218,12 +227,13 @@ static int send_pooled_buffers_to_port(MMAL_POOL_T *pool, MMAL_PORT_T *port)
         MMAL_BUFFER_HEADER_T *buffer = mmal_queue_get(pool->queue);
 
         if (!buffer) {
-            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Unable to get a required buffer %d from pool queue", i);
+            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+                ,_("Unable to get a required buffer %d from pool queue"), i);
             return MMALCAM_ERROR;
         }
 
         if (mmal_port_send_buffer(port, buffer) != MMAL_SUCCESS) {
-            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Unable to send a buffer to port (%d)", i);
+            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("Unable to send a buffer to port (%d)"), i);
             return MMALCAM_ERROR;
         }
     }
@@ -268,20 +278,20 @@ int mmalcam_start(struct context *cnt)
     mmalcam = cnt->mmalcam;
     mmalcam->cnt = cnt;
 
-    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO,
-            "MMAL Camera thread starting... for camera (%s) of %d x %d at %d fps",
-            cnt->conf.mmalcam_name, cnt->conf.width, cnt->conf.height, cnt->conf.frame_limit);
+    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO
+        ,_("MMAL Camera thread starting... for camera (%s) of %d x %d at %d fps")
+        ,cnt->conf.mmalcam_name, cnt->conf.width, cnt->conf.height, cnt->conf.framerate);
 
     mmalcam->camera_parameters = (RASPICAM_CAMERA_PARAMETERS*)malloc(sizeof(RASPICAM_CAMERA_PARAMETERS));
     if (mmalcam->camera_parameters == NULL) {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "camera params couldn't be allocated");
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("camera params couldn't be allocated"));
         return MMALCAM_ERROR;
     }
 
     raspicamcontrol_set_defaults(mmalcam->camera_parameters);
     mmalcam->width = cnt->conf.width;
     mmalcam->height = cnt->conf.height;
-    mmalcam->framerate = cnt->conf.frame_limit;
+    mmalcam->framerate = cnt->conf.framerate;
 
     if (cnt->conf.mmalcam_control_params) {
         parse_camera_control_params(cnt->conf.mmalcam_control_params, mmalcam->camera_parameters);
@@ -291,7 +301,6 @@ int mmalcam_start(struct context *cnt)
     cnt->imgs.height = mmalcam->height;
     cnt->imgs.size_norm = (mmalcam->width * mmalcam->height * 3) / 2;
     cnt->imgs.motionsize = mmalcam->width * mmalcam->height;
-    cnt->imgs.type = VIDEO_PALETTE_YUV420P;
 
     int retval = create_camera_component(mmalcam, cnt->conf.mmalcam_name);
 
@@ -301,7 +310,7 @@ int mmalcam_start(struct context *cnt)
 
     if (retval == 0) {
         if (mmal_port_enable(mmalcam->camera_capture_port, camera_buffer_callback)) {
-            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "MMAL camera capture port enabling failed");
+            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("MMAL camera capture port enabling failed"));
             retval = MMALCAM_ERROR;
         }
     }
@@ -309,7 +318,7 @@ int mmalcam_start(struct context *cnt)
     if (retval == 0) {
         if (mmal_port_parameter_set_boolean(mmalcam->camera_capture_port, MMAL_PARAMETER_CAPTURE, 1)
                 != MMAL_SUCCESS) {
-            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "MMAL camera capture start failed");
+            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, _("MMAL camera capture start failed"));
             retval = MMALCAM_ERROR;
         }
     }
@@ -339,7 +348,7 @@ int mmalcam_start(struct context *cnt)
  */
 void mmalcam_cleanup(struct mmalcam_context *mmalcam)
 {
-    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO, "MMAL Camera cleanup");
+    MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO, _("MMAL Camera cleanup"));
 
     if (mmalcam != NULL ) {
         if (mmalcam->camera_component) {
@@ -387,9 +396,10 @@ int mmalcam_next(struct context *cnt,  struct image_data *img_data)
         memcpy(img_data->image_norm, camera_buffer->data, cnt->imgs.size_norm);
         mmal_buffer_header_mem_unlock(camera_buffer);
     } else {
-        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "cmd %d flags %08x size %d/%d at %08x, img_size=%d",
-                camera_buffer->cmd, camera_buffer->flags, camera_buffer->length,
-                camera_buffer->alloc_size, camera_buffer->data, cnt->imgs.size_norm);
+        MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+            ,_("cmd %d flags %08x size %d/%d at %08x, img_size=%d")
+            ,camera_buffer->cmd, camera_buffer->flags, camera_buffer->length
+            ,camera_buffer->alloc_size, camera_buffer->data, cnt->imgs.size_norm);
     }
 
     mmal_buffer_header_release(camera_buffer);
@@ -403,7 +413,8 @@ int mmalcam_next(struct context *cnt,  struct image_data *img_data)
         }
 
         if (!new_buffer || status != MMAL_SUCCESS)
-            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO, "Unable to return a buffer to the camera video port");
+            MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
+                ,_("Unable to return a buffer to the camera video port"));
     }
 
     rotate_map(cnt,img_data);
