@@ -15,7 +15,29 @@
 #ifndef _INCLUDE_NETCAM_H
 #define _INCLUDE_NETCAM_H
 
+/* This is a workaround regarding these defines.  The config.h file defines
+ * HAVE_STDLIB_H as 1 whereas the jpeglib.h just defines it without a value.
+ * this causes massive warnings/error on mis-matched definitions.  We do not
+ * control either of these so we have to suffer through this workaround hack
+*/
+#if (HAVE_STDLIB_H == 1)
+    #undef HAVE_STDLIB_H
+    #define HAVE_STDLIB_H_ORIG 1
+#endif
+
 #include <jpeglib.h>
+
+#ifdef HAVE_STDLIB_H
+  #ifdef HAVE_STDLIB_H_ORIG
+    #undef HAVE_STDLIB_H
+    #undef HAVE_STDLIB_H_ORIG
+    #define HAVE_STDLIB_H 1
+  #else
+    #undef HAVE_STDLIB_H
+  #endif
+#endif
+
+
 #include <setjmp.h>
 #include <sys/socket.h>
 #include <sys/types.h>
@@ -215,8 +237,9 @@ typedef struct netcam_context {
     struct jpeg_error_mgr jerr;
     jmp_buf setjmp_buffer;
 
-    int jpeg_error;             /* flag to show error or warning
-                                   occurred during decompression*/
+    int jpeg_error;             /* flag to show error or warning occurred during decompression*/
+
+    int handler_finished;
 
 } netcam_context;
 
