@@ -18,6 +18,7 @@
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "translate.h"
 #include "md5.h"
 #include "picture.h"
 #include <sys/socket.h>
@@ -77,7 +78,8 @@ static int set_sock_timeout(int sock, int sec)
     tv.tv_usec = 0;
 
     if (setsockopt(sock, SOL_SOCKET, SO_RCVTIMEO, (char*) &tv, sizeof(tv))) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "set socket timeout failed");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("set socket timeout failed"));
         return 1;
     }
     return 0;
@@ -126,8 +128,8 @@ static int read_http_request(int sock, char* buffer, int buflen, char* uri, int
         nread += readb;
 
         if (nread > buflen) {
-            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "motion-stream End buffer reached"
-                      " waiting for buffer ending");
+            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+                ,_("motion-stream End buffer reached waiting for buffer ending"));
             break;
         }
 
@@ -144,7 +146,8 @@ static int read_http_request(int sock, char* buffer, int buflen, char* uri, int
             return 0;
         }
 
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "motion-stream READ give up!");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("motion-stream READ give up!"));
         return 0;
     }
 
@@ -202,8 +205,6 @@ static void* handle_basic_auth(void* param)
         "Pragma: no-cache\r\n"
         "WWW-Authenticate: Basic realm=\""STREAM_REALM"\"\r\n\r\n";
 
-    MOTION_PTHREAD_SETNAME("handle_basic_auth");
-
     pthread_mutex_lock(&stream_auth_mutex);
     p->thread_count++;
     pthread_mutex_unlock(&stream_auth_mutex);
@@ -242,7 +243,8 @@ static void* handle_basic_auth(void* param)
             free(authentication);
             char host[NI_MAXHOST] = "unknown";
             get_host(host, p->sock);
-            MOTION_LOG(ALR, TYPE_STREAM, NO_ERRNO, "motion-stream - failed auth attempt from %s", host);
+            MOTION_LOG(ALR, TYPE_STREAM, NO_ERRNO
+                ,_("motion-stream - failed auth attempt from %s"), host);
             goto Error;
         }
         free(authentication);
@@ -252,7 +254,7 @@ static void* handle_basic_auth(void* param)
 
     /* Set socket to non blocking */
     if (fcntl(p->sock, F_SETFL, p->sock_flags) < 0) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "fcntl");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("fcntl"));
         goto Error;
     }
 
@@ -271,7 +273,8 @@ static void* handle_basic_auth(void* param)
 
 Error:
     if (write(p->sock, request_auth_response_template, strlen (request_auth_response_template)) < 0)
-        MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO, "write failure 1:handle_basic_auth");
+        MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO
+            ,_("write failure 1:handle_basic_auth"));
 
 Invalid_Request:
     close(p->sock);
@@ -460,8 +463,6 @@ static void* handle_md5_digest(void* param)
         "</body>\n"
         "</html>\n";
 
-    MOTION_PTHREAD_SETNAME("handle_md5_digest");
-
     pthread_mutex_lock(&stream_auth_mutex);
     p->thread_count++;
     pthread_mutex_unlock(&stream_auth_mutex);
@@ -473,13 +474,15 @@ static void* handle_md5_digest(void* param)
     snprintf(server_nonce, SERVER_NONCE_LEN, "%08x%08x", rand1, rand2);
 
     if (!p->conf->stream_authentication) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error no authentication data");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("Error no authentication data"));
         goto InternalError;
     }
     h = strstr(p->conf->stream_authentication, ":");
 
     if (!h) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error no authentication data (no ':' found)");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("Error no authentication data (no ':' found)"));
         goto InternalError;
     }
 
@@ -487,7 +490,8 @@ static void* handle_md5_digest(void* param)
     server_pass = (char*)malloc(strlen(h) + 1);
 
     if (!server_user || !server_pass) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error malloc failed");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("Error malloc failed"));
         goto InternalError;
     }
 
@@ -594,7 +598,8 @@ static void* handle_md5_digest(void* param)
         } else {
             char host[NI_MAXHOST] = "unknown";
             get_host(host, p->sock);
-            MOTION_LOG(ALR, TYPE_STREAM, NO_ERRNO, "motion-stream - failed auth attempt from %s", host);
+            MOTION_LOG(ALR, TYPE_STREAM, NO_ERRNO
+                ,_("motion-stream - failed auth attempt from %s"), host);
         }
 
 Error:
@@ -609,16 +614,18 @@ Error:
                 request_auth_response_template, server_nonce,
                 KEEP_ALIVE_TIMEOUT, strlen(auth_failed_html_template));
         if (write(p->sock, buffer, strlen(buffer)) < 0)
-            MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO, "write failure 1:handle_md5_digest");
+            MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO
+                ,_("write failure 1:handle_md5_digest"));
         if (write(p->sock, auth_failed_html_template, strlen(auth_failed_html_template)) < 0)
-            MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO, "write failure 2:handle_md5_digest");
+            MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO
+                ,_("write failure 2:handle_md5_digest"));
     }
 
     // OK - Access
 
     /* Set socket to non blocking */
     if (fcntl(p->sock, F_SETFL, p->sock_flags) < 0) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "fcntl");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("fcntl"));
         goto Error;
     }
 
@@ -643,7 +650,8 @@ InternalError:
     free(server_pass);
 
     if (write(p->sock, internal_error_template, strlen(internal_error_template)) < 0)
-      MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO, "write failure 3:handle_md5_digest");
+      MOTION_LOG(DBG, TYPE_STREAM, SHOW_ERRNO
+        ,_("write failure 3:handle_md5_digest"));
 
 Invalid_Request:
     close(p->sock);
@@ -686,7 +694,8 @@ static void do_client_auth(struct context *cnt, struct stream *stm, int *stream_
       handle_func = handle_md5_digest;
       break;
     default:
-      MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error unknown stream authentication method");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+            ,_("Error unknown stream authentication method"));
       goto Error;
       break;
     }
@@ -701,13 +710,13 @@ static void do_client_auth(struct context *cnt, struct stream *stm, int *stream_
 
     /* Set socket to blocking */
     if ((flags = fcntl(sc, F_GETFL, 0)) < 0) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "fcntl");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, _("fcntl"));
         goto Error;
     }
     handle_param->sock_flags = flags;
 
     if (fcntl(sc, F_SETFL, flags & (~O_NONBLOCK)) < 0) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "fcntl");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, _("fcntl"));
         goto Error;
     }
 
@@ -715,18 +724,18 @@ static void do_client_auth(struct context *cnt, struct stream *stm, int *stream_
         goto Error;
 
     if (pthread_attr_init(&attr)) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error pthread_attr_init");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("Error pthread_attr_init"));
         goto Error;
     }
 
     if (pthread_create(&thread_id, &attr, handle_func, handle_param)) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error pthread_create");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("Error pthread_create"));
         goto Error;
     }
     pthread_detach(thread_id);
 
     if (pthread_attr_destroy(&attr))
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error pthread_attr_destroy");
+        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("Error pthread_attr_destroy"));
 
     return;
 
@@ -749,16 +758,20 @@ int http_bindsock(int port, int local, int ipv6_enabled)
 {
     int sd = socket(ipv6_enabled?AF_INET6:AF_INET, SOCK_STREAM, IPPROTO_TCP);
 
-    if (sd == -1)
-    {
-        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "error creating socket");
+    if (sd == -1){
+        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO,_("error creating socket"));
         return -1;
     }
+    /* We can not do a SOCK_CLOEXEC on open since it is not supported on all platforms*/
+    if (fcntl(sd, F_SETFD, FD_CLOEXEC) == -1){
+        MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO,_("Unable to set FD_CLOEXEC"));
+    };
 
     int yes = 1, no = 0;
     if (setsockopt(sd, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes)) != 0)
     {
-        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "setting SO_REUSEADDR to yes failed");
+        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO
+            ,_("setting SO_REUSEADDR to yes failed"));
         /* we can carry on even if this failed */
     }
 
@@ -766,7 +779,8 @@ int http_bindsock(int port, int local, int ipv6_enabled)
     {
         if (setsockopt(sd, IPPROTO_IPV6, IPV6_V6ONLY, &no, sizeof(no)) != 0)
         {
-            MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "setting IPV6_V6ONLY to no failed");
+            MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO
+                ,_("setting IPV6_V6ONLY to no failed"));
             /* we can carry on even if this failed */
         }
     }
@@ -803,18 +817,20 @@ int http_bindsock(int port, int local, int ipv6_enabled)
     }
 
     if (bind(sd, (struct sockaddr*)&sin, sinsize) != 0) {
-        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "error binding on %s port %d", addr_str, port);
+        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO
+            ,_("error binding on %s port %d"), addr_str, port);
         close(sd);
         return -1;
     }
 
     if (listen(sd, DEF_MAXWEBQUEUE) != 0) {
-        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "error listening");
+        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO,_("error listening"));
         close(sd);
         return -1;
     }
 
-    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO, "listening on %s port %d", addr_str, port);
+    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO
+        ,_("listening on %s port %d"), addr_str, port);
 
     return sd;
 }
@@ -833,7 +849,7 @@ static int http_acceptsock(int sl)
     sc = accept(sl, (struct sockaddr*)&addr, &addr_len);
 
     if (sc < 0) {
-        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO, "motion-stream accept()");
+        MOTION_LOG(CRT, TYPE_STREAM, SHOW_ERRNO,_("motion-stream accept()"));
         return -1;
     }
 
@@ -908,6 +924,7 @@ static void stream_flush(struct stream *list, int *stream_count, int lim)
                 if (--client->tmpbuffer->ref <= 0) {
                     free(client->tmpbuffer->ptr);
                     free(client->tmpbuffer);
+                    if (client->cors_header != NULL) free(client->cors_header);
                 }
 
                 /* Mark this client's buffer as empty. */
@@ -969,6 +986,16 @@ static struct stream_buffer *stream_tmpbuffer(int size)
     return tmpbuffer;
 }
 
+const char *base_header = "HTTP/1.0 200 OK\r\n"
+                          "Server: Motion/"VERSION"\r\n"
+                          "Connection: close\r\n"
+                          "Max-Age: 0\r\n"
+                          "Expires: 0\r\n"
+                          "Cache-Control: no-cache, private\r\n"
+                          "Pragma: no-cache\r\n"
+                          "Content-Type: multipart/x-mixed-replace; "
+                          "boundary=BoundaryString\r\n\r\n";
+#define BASE_HEADER_LEN strlen(base_header)
 /**
  * stream_add_client
  *
@@ -977,24 +1004,43 @@ static struct stream_buffer *stream_tmpbuffer(int size)
 static void stream_add_client(struct stream *list, int sc)
 {
     struct stream *new = mymalloc(sizeof(struct stream));
-    static const char header[] = "HTTP/1.0 200 OK\r\n"
-                                 "Server: Motion/"VERSION"\r\n"
-                                 "Connection: close\r\n"
-                                 "Max-Age: 0\r\n"
-                                 "Expires: 0\r\n"
-                                 "Cache-Control: no-cache, private\r\n"
-                                 "Pragma: no-cache\r\n"
-                                 "Content-Type: multipart/x-mixed-replace; "
-                                 "boundary=BoundaryString\r\n\r\n";
-
     memset(new, 0, sizeof(struct stream));
     new->socket = sc;
 
-    if ((new->tmpbuffer = stream_tmpbuffer(sizeof(header))) == NULL) {
-        MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error creating tmpbuffer in stream_add_client");
+    // Copy the HTTP headers into tmpbuffer.
+
+    if (list->cors_header == NULL) {
+
+        new->tmpbuffer = stream_tmpbuffer(BASE_HEADER_LEN);
+        if (new->tmpbuffer == NULL) {
+            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+                ,_("Error creating tmpbuffer in stream_add_client"));
+        } else {
+            memcpy(new->tmpbuffer->ptr, base_header, BASE_HEADER_LEN);
+            new->tmpbuffer->size = BASE_HEADER_LEN;
+        }
+
     } else {
-        memcpy(new->tmpbuffer->ptr, header, sizeof(header)-1);
-        new->tmpbuffer->size = sizeof(header)-1;
+
+        const char *cors_header_key = "Access-Control-Allow-Origin: ";
+        size_t cors_header_key_len = strlen(cors_header_key);
+        size_t cors_header_len = strlen(list->cors_header);
+        size_t size = BASE_HEADER_LEN-2 + cors_header_key_len + cors_header_len + 4;
+
+        new->tmpbuffer = stream_tmpbuffer(size);
+        if (new->tmpbuffer == NULL) {
+            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+                ,_("Error creating tmpbuffer in stream_add_client"));
+        } else {
+            // Basically copy over the base headers (without the second \r\n),
+            // and then the CORS header key, value, and \r\n\r\n.
+            memcpy(new->tmpbuffer->ptr, base_header, BASE_HEADER_LEN-2);
+            memcpy(&new->tmpbuffer->ptr[BASE_HEADER_LEN-2], cors_header_key, cors_header_key_len);
+            memcpy(&new->tmpbuffer->ptr[BASE_HEADER_LEN-2 + cors_header_key_len], list->cors_header, cors_header_len);
+            memcpy(&new->tmpbuffer->ptr[BASE_HEADER_LEN-2 + cors_header_key_len + cors_header_len], "\r\n\r\n", 4);
+            new->tmpbuffer->size = size;
+        }
+
     }
 
     new->prev = list;
@@ -1066,11 +1112,29 @@ static int stream_check_write(struct stream *list)
  *
  * Returns: stream socket descriptor.
  */
-int stream_init(struct stream *stm, int stream_port, int stream_localhost, int ipv6_enabled)
+int stream_init(struct stream *stm,
+                int port,
+                int localhost,
+                int ipv6_enabled,
+                const char *cors_header)
 {
-    stm->socket = http_bindsock(stream_port, stream_localhost, ipv6_enabled);
+    stm->socket = http_bindsock(port, localhost, ipv6_enabled);
     stm->next = NULL;
     stm->prev = NULL;
+    stm->cors_header = NULL;
+
+    if (cors_header != NULL) {
+
+        size_t size = strlen(cors_header) + 1;
+        stm->cors_header = mymalloc(size);
+        if (stm->cors_header == NULL) {
+            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO
+                ,_("Error allocated cors_header in stream_init"));
+            return stm->socket;
+        }
+        memcpy(stm->cors_header, cors_header, size);
+
+    }
 
     return stm->socket;
 }
@@ -1086,11 +1150,12 @@ void stream_stop(struct stream *stm)
     struct stream *next = stm->next;
 
     /* TODO friendly info which socket is closing */
-    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO, "Closing motion-stream listen socket"
-               " & active motion-stream sockets");
+    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO
+        ,_("Closing motion-stream listen socket & active motion-stream sockets"));
 
     close(stm->socket);
     stm->socket = -1;
+    free(stm->cors_header);
 
     while (next) {
         list = next;
@@ -1099,14 +1164,15 @@ void stream_stop(struct stream *stm)
         if (list->tmpbuffer) {
             free(list->tmpbuffer->ptr);
             free(list->tmpbuffer);
+            if (list->cors_header != NULL) free(list->cors_header);
         }
 
         close(list->socket);
         free(list);
     }
 
-    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO, "Closed motion-stream listen socket"
-               " & active motion-stream sockets");
+    MOTION_LOG(NTC, TYPE_STREAM, NO_ERRNO
+        ,_("Closed motion-stream listen socket & active motion-stream sockets"));
 }
 
 /*
@@ -1176,22 +1242,6 @@ void stream_put(struct context *cnt, struct stream *stm, int *stream_count, unsi
     if (*stream_count <= 0)
         return;
 
-    /* substream put - scale image down and update pointer to the scaled buffer */
-    if (do_scale_down) {
-        /* TODO for now just scale 50%, better resize image to a config predefined size */
-
-        int origwidth = cnt->imgs.width, origheight = cnt->imgs.height;
-        int subwidth = origwidth/2, subheight = origheight/2;
-        int subsize = subwidth * subheight * 3 / 2;
-
-        /* allocate new buffer and scale image */
-        img = scale_half_yuv420p (origwidth, origheight, img);
-
-        image_width = subwidth;
-        image_height = subheight;
-        image_size = subsize;
-    }
-
     /* Lock the mutex */
     if (cnt->conf.stream_auth_method != 0)
         pthread_mutex_lock(&stream_auth_mutex);
@@ -1256,7 +1306,7 @@ void stream_put(struct context *cnt, struct stream *stm, int *stream_count, unsi
              */
             stream_add_write(stm, tmpbuffer, cnt->conf.stream_maxrate);
         } else {
-            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO, "Error creating tmpbuffer");
+            MOTION_LOG(ERR, TYPE_STREAM, SHOW_ERRNO,_("Error creating tmpbuffer"));
         }
     }
 
