@@ -6,6 +6,7 @@
  *    This program is published under the GNU Public license
  */
 #include <math.h>
+#include "translate.h"
 #include "motion.h"
 
 #ifdef HAVE_V4L2
@@ -33,12 +34,11 @@ struct trackoptions track_template = {
     .minmaxfound =     0,              /* flag for minmax values stored for pwc based camera */
     .step_angle_x =    10,             /* UVC step angle in degrees X-axis that camera moves during auto tracking */
     .step_angle_y =    10,             /* UVC step angle in degrees Y-axis that camera moves during auto tracking */
-    .move_wait =       10              /* number of frames to disable motion detection after camera moving */
+    .move_wait =       10,             /* number of frames to disable motion detection after camera moving */
+    .generic_move =    NULL            /* command to execute to move a generic camera */
 };
 
 
-
-
 /* Add your own center and move functions here: */
 
 static unsigned int servo_position(struct context *cnt, unsigned int motor);
@@ -49,22 +49,28 @@ static unsigned int iomojo_center(struct context *cnt, int xoff, int yoff);
 
 static unsigned int stepper_move(struct context *cnt, struct coord *cent, struct images *imgs);
 static unsigned int servo_move(struct context *cnt, struct coord *cent,
-                                     struct images *imgs, unsigned int manual);
+                               struct images *imgs, unsigned int manual);
 static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent, struct images *imgs);
 
 #ifdef HAVE_V4L2
 static unsigned int lqos_center(struct context *cnt, int dev, int xoff, int yoff);
 static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
-                                    struct images *imgs, unsigned int manual);
+                              struct images *imgs, unsigned int manual);
 static unsigned int uvc_center(struct context *cnt, int dev, int xoff, int yoff);
 static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
-                                   struct images *imgs, unsigned int manual);
+                             struct images *imgs, unsigned int manual);
 #endif /* HAVE_V4L2 */
 
+static unsigned int generic_move(struct context *cnt, enum track_action action, unsigned int manual,
+                                 int xoff, int yoff, struct coord *cent, struct images *imgs);
+
+
 /* Add a call to your functions here: */
 unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
-                                unsigned int manual, int xoff, int yoff)
+                          unsigned int manual, int xoff, int yoff)
 {
+    struct coord cent;
+
     if (!manual && !cnt->track.active)
         return 0;
 
@@ -72,7 +78,7 @@ unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
         unsigned int ret;
         ret = stepper_center(cnt, xoff, yoff);
         if (!ret) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "internal error");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("internal error"));
             return 0;
         }
         else return ret;
@@ -87,18 +93,25 @@ unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
 #endif
     else if (cnt->track.type == TRACK_TYPE_IOMOJO)
         return iomojo_center(cnt, xoff, yoff);
-    else if (cnt->track.type == TRACK_TYPE_GENERIC)
-        return 10; // FIX ME. I chose to return something reasonable.
+    else if (cnt->track.type == TRACK_TYPE_GENERIC) {
+        if (cnt->track.generic_move){
+            cent.x = -cnt->track_posx;
+            cent.y = -cnt->track_posy;
+            return generic_move(cnt, TRACK_CENTER, manual,0 ,0 ,&cent , NULL);
+        } else {
+            return 10; // FIX ME. I chose to return something reasonable.
+        }
+    }
 
-    MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "internal error, %hu is not a known track-type",
-               cnt->track.type);
+    MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+        ,_("internal error, %hu is not a known track-type"), cnt->track.type);
 
     return 0;
 }
 
 /* Add a call to your functions here: */
 unsigned int track_move(struct context *cnt, int dev, struct coord *cent, struct images *imgs,
-                              unsigned int manual)
+                        unsigned int manual)
 {
 
     if (!manual && !cnt->track.active)
@@ -116,11 +129,15 @@ unsigned int track_move(struct context *cnt, int dev, struct coord *cent, struct
 #endif
     else if (cnt->track.type == TRACK_TYPE_IOMOJO)
         return iomojo_move(cnt, dev, cent, imgs);
-    else if (cnt->track.type == TRACK_TYPE_GENERIC)
-        return cnt->track.move_wait; // FIX ME. I chose to return something reasonable.
+    else if (cnt->track.type == TRACK_TYPE_GENERIC) {
+        if (cnt->track.generic_move)
+          return generic_move(cnt, TRACK_MOVE, manual, 0, 0, cent, imgs);
+        else
+          return cnt->track.move_wait; // FIX ME. I chose to return something reasonable.
+    }
 
-    MOTION_LOG(WRN, TYPE_TRACK, SHOW_ERRNO, "internal error, %hu is not a known track-type",
-               cnt->track.type);
+    MOTION_LOG(WRN, TYPE_TRACK, SHOW_ERRNO
+        ,_("internal error, %hu is not a known track-type"), cnt->track.type);
 
     return 0;
 }
@@ -142,15 +159,16 @@ static unsigned int stepper_command(struct context *cnt, unsigned int motor,
     buffer[2] = data;
 
     if (write(cnt->track.dev, buffer, 3) != 3) {
-        MOTION_LOG(NTC, TYPE_TRACK, SHOW_ERRNO, "port %s dev fd %i, motor %hu command %hu data %hu",
-                   cnt->track.port, cnt->track.dev, motor, command, data);
+        MOTION_LOG(NTC, TYPE_TRACK, SHOW_ERRNO
+            ,_("port %s dev fd %i, motor %hu command %hu data %hu")
+            ,cnt->track.port, cnt->track.dev, motor, command, data);
         return 0;
     }
 
     while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1);
 
     if (time(NULL) >= timeout + 2) {
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Status byte timeout!");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Status byte timeout!"));
         return 0;
     }
 
@@ -169,11 +187,12 @@ static unsigned int stepper_center(struct context *cnt, int x_offset, int y_offs
     struct termios adtio;
 
     if (cnt->track.dev < 0) {
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Try to open serial device %s", cnt->track.port);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("Try to open serial device %s"), cnt->track.port);
 
-        if ((cnt->track.dev = open(cnt->track.port, O_RDWR | O_NOCTTY)) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to open serial device %s",
-                       cnt->track.port);
+        if ((cnt->track.dev = open(cnt->track.port, O_RDWR|O_CLOEXEC | O_NOCTTY)) < 0) {
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Unable to open serial device %s"), cnt->track.port);
             return 0;
         }
 
@@ -187,13 +206,14 @@ static unsigned int stepper_center(struct context *cnt, int x_offset, int y_offs
         tcflush (cnt->track.dev, TCIFLUSH);
 
         if (tcsetattr(cnt->track.dev, TCSANOW, &adtio) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to initialize serial device %s",
-                       cnt->track.port);
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Unable to initialize serial device %s"), cnt->track.port);
             cnt->track.dev = -1;
             return 0;
         }
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Opened serial device %s and initialize, fd %i",
-                   cnt->track.port, cnt->track.dev);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("Opened serial device %s and initialize, fd %i")
+            ,cnt->track.port, cnt->track.dev);
     }
 
     /* x-axis */
@@ -224,22 +244,25 @@ static unsigned int stepper_center(struct context *cnt, int x_offset, int y_offs
 }
 
 static unsigned int stepper_move(struct context *cnt,
-                                       struct coord *cent, struct images *imgs)
+                                 struct coord *cent, struct images *imgs)
 {
     unsigned int command = 0, data = 0;
 
     if (cnt->track.dev < 0) {
-        MOTION_LOG(WRN, TYPE_TRACK, NO_ERRNO, "No device %s started yet , trying stepper_center()",
-                   cnt->track.port);
+        MOTION_LOG(WRN, TYPE_TRACK, NO_ERRNO
+            ,_("No device %s started yet , trying stepper_center()")
+            ,cnt->track.port);
 
         if (!stepper_center(cnt, 0, 0)) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "failed to initialize stepper device on %s , fd [%i].",
-                       cnt->track.port, cnt->track.dev);
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("failed to initialize stepper device on %s , fd [%i].")
+                ,cnt->track.port, cnt->track.dev);
             return 0;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "succeed , device started %s , fd [%i]",
-                    cnt->track.port, cnt->track.dev);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("succeed , device started %s , fd [%i]")
+            ,cnt->track.port, cnt->track.dev);
     }
 
     /* x-axis */
@@ -289,9 +312,9 @@ static int servo_open(struct context *cnt)
 {
     struct termios adtio;
 
-    if ((cnt->track.dev = open(cnt->track.port, O_RDWR | O_NOCTTY)) < 0) {
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to open serial device %s",
-                   cnt->track.port);
+    if ((cnt->track.dev = open(cnt->track.port, O_RDWR|O_CLOEXEC | O_NOCTTY)) < 0) {
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+            ,_("Unable to open serial device %s"),cnt->track.port);
         return 0;
     }
 
@@ -305,14 +328,15 @@ static int servo_open(struct context *cnt)
     tcflush (cnt->track.dev, TCIFLUSH);
 
     if (tcsetattr(cnt->track.dev, TCSANOW, &adtio) < 0) {
-        MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "Unable to initialize serial device %s",
-                   cnt->track.port);
+        MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO
+            ,_("Unable to initialize serial device %s"), cnt->track.port);
         cnt->track.dev = -1;
         return 0;
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Opened serial device %s and initialize, fd %i",
-               cnt->track.port, cnt->track.dev);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("Opened serial device %s and initialize, fd %i")
+        ,cnt->track.port, cnt->track.dev);
 
     return 1;
 }
@@ -329,23 +353,26 @@ static unsigned int servo_command(struct context *cnt, unsigned int motor,
     buffer[2] = data;
 
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "SENDS port %s dev fd %i, motor %hu command %hu data %hu",
-               cnt->track.port, cnt->track.dev, buffer[0], buffer[1], buffer[2]);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("SENDS port %s dev fd %i, motor %hu command %hu data %hu")
+        ,cnt->track.port, cnt->track.dev, buffer[0], buffer[1], buffer[2]);
 
     if (write(cnt->track.dev, buffer, 3) != 3) {
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "port %s dev fd %i, motor %hu command %hu data %hu",
-                   cnt->track.port, cnt->track.dev, motor, command, data);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("port %s dev fd %i, motor %hu command %hu data %hu")
+            ,cnt->track.port, cnt->track.dev, motor, command, data);
         return 0;
     }
 
     while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1);
 
     if (time(NULL) >= timeout + 2) {
-        MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "Status byte timeout!");
+        MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO,_("Status byte timeout!"));
         return 0;
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Command return %d", buffer[0]);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("Command return %d"), buffer[0]);
 
 
     return buffer[0];
@@ -368,7 +395,7 @@ static unsigned int servo_position(struct context *cnt, unsigned int motor)
  *
  */
 static unsigned int servo_move(struct context *cnt, struct coord *cent,
-                                     struct images *imgs, unsigned int manual)
+                               struct images *imgs, unsigned int manual)
 {
     unsigned int command = 0;
     unsigned int data = 0;
@@ -377,14 +404,15 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
     /* If device is not open yet , open and center */
     if (cnt->track.dev < 0) {
         if (!servo_center(cnt, 0, 0)) {
-            MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "Problem opening servo!");
+            MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO,_("Problem opening servo!"));
             return 0;
         }
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "cent->x %d, cent->y %d, reversex %d,"
-               "reversey %d manual %d", cent->x , cent->y,
-               cnt->track.motorx_reverse, cnt->track.motory_reverse, manual);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("cent->x %d, cent->y %d, reversex %d, reversey %d manual %d")
+        ,cent->x , cent->y, cnt->track.motorx_reverse
+        ,cnt->track.motory_reverse, manual);
 
     if (manual) {
         int offset;
@@ -404,8 +432,9 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
             if ((data + position > (unsigned)cnt->track.maxx) ||
                 (position - offset < (unsigned)cnt->track.minx)) {
-                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "x %d value out of range! (%d - %d)",
-                           data, cnt->track.minx, cnt->track.maxx);
+                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO
+                    ,_("x %d value out of range! (%d - %d)")
+                    ,data, cnt->track.minx, cnt->track.maxx);
                 return 0;
             }
 
@@ -429,8 +458,9 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
             if ((data + position > (unsigned)cnt->track.maxy) ||
                 (position - offset < (unsigned)cnt->track.miny)) {
-                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "y %d value out of range! (%d - %d)",
-                           data, cnt->track.miny, cnt->track.maxy);
+                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO
+                    ,_("y %d value out of range! (%d - %d)")
+                    ,data, cnt->track.miny, cnt->track.maxy);
                 return 0;
             }
 
@@ -461,7 +491,7 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
         }
 
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "X offset %d", data);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO,_("X offset %d"), data);
 
         data = data * cnt->track.stepsize / imgs->width;
 
@@ -472,8 +502,9 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
             if ((position + data > (unsigned)cnt->track.maxx) ||
                 (position - data < (unsigned)cnt->track.minx)) {
-                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "x %d value out of range! (%d - %d)",
-                           data, cnt->track.minx, cnt->track.maxx);
+                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO
+                    ,_("x %d value out of range! (%d - %d)")
+                    ,data, cnt->track.minx, cnt->track.maxx);
                 return 0;
             }
 
@@ -482,10 +513,11 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
             servo_command(cnt, cnt->track.motorx, SERVO_COMMAND_SPEED, cnt->track.speed);
             servo_command(cnt, cnt->track.motorx, command, data);
 
-            MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "X cent->x %d, cent->y %d, reversex %d,"
-                       "reversey %d motorx %d data %d command %d",
-                       cent->x, cent->y, cnt->track.motorx_reverse,
-                       cnt->track.motory_reverse, cnt->track.motorx, data, command);
+            MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+                ,_("X cent->x %d, cent->y %d, reversex %d,"
+                "reversey %d motorx %d data %d command %d")
+                ,cent->x, cent->y, cnt->track.motorx_reverse
+                ,cnt->track.motory_reverse, cnt->track.motorx, data, command);
         }
 
         /***** y-axis *****/
@@ -508,7 +540,7 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
             data = cent->y - imgs->height / 2;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Y offset %d", data);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO,_("Y offset %d"), data);
 
         data = data * cnt->track.stepsize / imgs->height;
 
@@ -519,8 +551,9 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
             if ((position + data > (unsigned)cnt->track.maxy) ||
                 (position - data < (unsigned)cnt->track.miny)) {
-                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "y %d value out of range! (%d - %d)",
-                           data, cnt->track.miny, cnt->track.maxy);
+                MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO
+                    ,_("y %d value out of range! (%d - %d)")
+                    ,data, cnt->track.miny, cnt->track.maxy);
                 return 0;
             }
 
@@ -528,10 +561,11 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
             servo_command(cnt, cnt->track.motory, SERVO_COMMAND_SPEED, cnt->track.speed);
             servo_command(cnt, cnt->track.motory, command, data);
 
-            MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Y cent->x %d, cent->y %d, reversex %d,"
-                       "reversey %d motory %d data %d command %d",
-                        cent->x, cent->y, cnt->track.motorx_reverse,
-                        cnt->track.motory_reverse, cnt->track.motory, command);
+            MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+                ,_("Y cent->x %d, cent->y %d, reversex %d,"
+                "reversey %d motory %d data %d command %d")
+                ,cent->x, cent->y, cnt->track.motorx_reverse
+                ,cnt->track.motory_reverse, cnt->track.motory, command);
         }
     }
 
@@ -563,17 +597,19 @@ static unsigned int servo_center(struct context *cnt, int x_offset, int y_offset
     /* If device is not open yet */
     if (cnt->track.dev < 0) {
         if (!servo_open(cnt)) {
-            MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO, "Problem opening servo!");
+            MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO,_("Problem opening servo!"));
             return 0;
         }
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "X-offset %d, Y-offset %d, x-position %d. y-position %d,"
-               "reversex %d, reversey %d , stepsize %d", x_offset, y_offset,
-               cnt->track.homex + (x_offset * cnt->track.stepsize),
-               cnt->track.homey + (y_offset * cnt->track.stepsize),
-               cnt->track.motorx_reverse, cnt->track.motory_reverse,
-               cnt->track.stepsize);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("X-offset %d, Y-offset %d, x-position %d. y-position %d,"
+        "reversex %d, reversey %d , stepsize %d")
+        ,x_offset, y_offset
+        ,cnt->track.homex + (x_offset * cnt->track.stepsize)
+        ,cnt->track.homey + (y_offset * cnt->track.stepsize)
+        ,cnt->track.motorx_reverse, cnt->track.motory_reverse
+        ,cnt->track.stepsize);
 
     /* x-axis */
     if (cnt->track.motorx_reverse)
@@ -621,7 +657,7 @@ static char iomojo_command(struct context *cnt, char *command, int len, unsigned
         while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 2);
 
         if (time(NULL) >= timeout + 2) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Return byte timeout!");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Return byte timeout!"));
             return 0;
         }
     }
@@ -638,7 +674,7 @@ static void iomojo_setspeed(struct context *cnt, unsigned int speed)
     command[2] = speed;
 
     if (iomojo_command(cnt, command, 3, 1) != IOMOJO_SETSPEED_RET)
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to set camera speed");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Unable to set camera speed"));
 }
 
 static void iomojo_movehome(struct context *cnt)
@@ -657,9 +693,9 @@ static unsigned int iomojo_center(struct context *cnt, int x_offset, int y_offse
     char command[5], direction = 0;
 
     if (cnt->track.dev < 0) {
-        if ((cnt->track.dev = open(cnt->track.port, O_RDWR | O_NOCTTY)) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to open serial device %s",
-                       cnt->track.port);
+        if ((cnt->track.dev = open(cnt->track.port, O_RDWR|O_CLOEXEC | O_NOCTTY)) < 0) {
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Unable to open serial device %s"), cnt->track.port);
             return 0;
         }
 
@@ -672,8 +708,8 @@ static unsigned int iomojo_center(struct context *cnt, int x_offset, int y_offse
         adtio.c_cc[VMIN] = 0;   /* blocking read until 1 char */
         tcflush(cnt->track.dev, TCIFLUSH);
         if (tcsetattr(cnt->track.dev, TCSANOW, &adtio) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Unable to initialize serial device %s",
-                       cnt->track.port);
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Unable to initialize serial device %s"), cnt->track.port);
             return 0;
         }
     }
@@ -710,7 +746,7 @@ static unsigned int iomojo_center(struct context *cnt, int x_offset, int y_offse
         iomojo_command(cnt, command, 5, 0);
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "succeed");
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO,_("succeed"));
 
     return cnt->track.move_wait;
 }
@@ -790,14 +826,16 @@ static unsigned int lqos_center(struct context *cnt, int dev, int x_angle, int y
     if (cnt->track.dev == -1) {
 
         if (ioctl(dev, VIDIOCPWCMPTRESET, &reset) == -1) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to reset pwc camera to starting position! Reason");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to reset pwc camera to starting position! Reason"));
             return 0;
         }
 
         SLEEP(6, 0);
 
         if (ioctl(dev, VIDIOCPWCMPTGRANGE, &pmr) == -1) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "failed VIDIOCPWCMPTGRANGE");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("failed VIDIOCPWCMPTGRANGE"));
             return 0;
         }
 
@@ -810,7 +848,8 @@ static unsigned int lqos_center(struct context *cnt, int dev, int x_angle, int y
     }
 
     if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "ioctl VIDIOCPWCMPTGANGLE");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+            ,_("ioctl VIDIOCPWCMPTGANGLE"));
 
     pma.absolute = 1;
 
@@ -821,11 +860,12 @@ static unsigned int lqos_center(struct context *cnt, int dev, int x_angle, int y
         pma.tilt = y_angle * 100;
 
     if (ioctl(dev, VIDIOCPWCMPTSANGLE, &pma) == -1) {
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to pan/tilt pwc camera! Reason");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+            ,_("Failed to pan/tilt pwc camera! Reason"));
         return 0;
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "succeed");
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO,_("succeed"));
 
     return cnt->track.move_wait;
 }
@@ -856,7 +896,8 @@ static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
     /* If we never checked for the min/max values for pan/tilt we do it now */
     if (cnt->track.minmaxfound == 0) {
         if (ioctl(dev, VIDIOCPWCMPTGRANGE, &pmr) == -1) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "failed VIDIOCPWCMPTGRANGE");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("failed VIDIOCPWCMPTGRANGE"));
             return 0;
         }
         cnt->track.minmaxfound = 1;
@@ -868,7 +909,8 @@ static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
 
     /* Get current camera position */
     if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "ioctl VIDIOCPWCMPTGANGLE");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+            ,_("ioctl VIDIOCPWCMPTGANGLE"));
 
 
     /*
@@ -893,7 +935,8 @@ static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
     pma.tilt = move_y_degrees;
 
     if (ioctl(dev, VIDIOCPWCMPTSANGLE, &pma) == -1) {
-        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to pan/tilt pwc camera! Reason");
+        MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+            ,_("Failed to pan/tilt pwc camera! Reason"));
         return 0;
     }
 
@@ -931,7 +974,8 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         control_s.value = (unsigned char) reset;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to reset UVC camera to starting position! Reason");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to reset UVC camera to starting position! Reason"));
             return 0;
         }
 
@@ -939,11 +983,13 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         control_s.value = (unsigned char) reset;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to reset UVC camera to starting position! Reason");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to reset UVC camera to starting position! Reason"));
             return 0;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Reseting UVC camera to starting position");
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("Reseting UVC camera to starting position"));
 
         SLEEP(8, 0);
 
@@ -952,11 +998,11 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         queryctrl.id = V4L2_CID_PAN_RELATIVE;
 
         if (ioctl(dev, VIDIOC_QUERYCTRL, &queryctrl) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "ioctl querycontrol");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("ioctl querycontrol"));
             return 0;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Getting camera range");
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO,_("Getting camera range"));
 
        /* DWe 30.03.07 The orig request failed :
         * must be VIDIOC_G_CTRL separate for pan and tilt or via VIDIOC_G_EXT_CTRLS - now for 1st manual
@@ -983,10 +1029,12 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
 
     struct v4l2_control control_s;
 
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "INPUT_PARAM_ABS pan_min %d,pan_max %d,tilt_min %d,tilt_max %d ",
-               cnt->track.minx, cnt->track.maxx, cnt->track.miny, cnt->track.maxy);
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "INPUT_PARAM_ABS X_Angel %d, Y_Angel %d ",
-               x_angle, y_angle);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("INPUT_PARAM_ABS pan_min %d,pan_max %d,tilt_min %d,tilt_max %d ")
+        ,cnt->track.minx, cnt->track.maxx, cnt->track.miny, cnt->track.maxy);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("INPUT_PARAM_ABS X_Angel %d, Y_Angel %d ")
+        ,x_angle, y_angle);
 
     if (x_angle <= cnt->track.maxx && x_angle >= cnt->track.minx)
         move_x_degrees = x_angle - (cnt->track.pan_angle);
@@ -1004,8 +1052,9 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
     pan.s16.pan = -move_x_degrees * INCPANTILT;
     pan.s16.tilt = -move_y_degrees * INCPANTILT;
 
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "For_SET_ABS move_X %d,move_Y %d",
-               move_x_degrees, move_y_degrees);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("For_SET_ABS move_X %d,move_Y %d")
+        ,move_x_degrees, move_y_degrees);
 
     /* DWe 30.03.07 Must be broken in diff calls, because
      * one call for both is not accept via VIDIOC_S_CTRL -> maybe via VIDIOC_S_EXT_CTRLS
@@ -1018,7 +1067,7 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         control_s.value = pan.s16.pan;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to move UVC camera!");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Failed to move UVC camera!"));
             return 0;
         }
     }
@@ -1033,17 +1082,18 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         control_s.value = pan.s16.tilt;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to move UVC camera!");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Failed to move UVC camera!"));
             return 0;
         }
     }
 
-    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Found MINMAX = %d",
-               cnt->track.minmaxfound);
+    MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+        ,_("Found MINMAX = %d"),cnt->track.minmaxfound);
 
     if (cnt->track.dev != -1) {
-        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "Before_ABS_Y_Angel : x= %d , Y= %d, ",
-                   cnt->track.pan_angle, cnt->track.tilt_angle);
+        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+            ,_("Before_ABS_Y_Angel : x= %d , Y= %d, ")
+            ,cnt->track.pan_angle, cnt->track.tilt_angle);
 
         if (move_x_degrees != -1) {
             cnt->track.pan_angle += move_x_degrees;
@@ -1053,8 +1103,9 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
             cnt->track.tilt_angle += move_y_degrees;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "After_ABS_Y_Angel : x= %d , Y= %d",
-                   cnt->track.pan_angle, cnt->track.tilt_angle);
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("After_ABS_Y_Angel : x= %d , Y= %d")
+            ,cnt->track.pan_angle, cnt->track.tilt_angle);
     }
 
     return cnt->track.move_wait;
@@ -1083,7 +1134,8 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
         control_s.value = (unsigned char) reset;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to reset UVC camera to starting position! Reason");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to reset UVC camera to starting position! Reason"));
             return 0;
         }
 
@@ -1091,11 +1143,13 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
         control_s.value = (unsigned char) reset;
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to reset UVC camera to starting position! Reason");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to reset UVC camera to starting position! Reason"));
             return 0;
         }
 
-        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO, "Reseting UVC camera to starting position");
+        MOTION_LOG(NTC, TYPE_TRACK, NO_ERRNO
+            ,_("Reseting UVC camera to starting position"));
 
         /* set the "helpvalue" back to null because after reset CAM should be in x=0 and not 70 */
         cent->x = 0;
@@ -1162,11 +1216,14 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
             move_y_degrees = cnt->track.maxy - cnt->track.tilt_angle;
     }
 
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "For_SET_REL pan_min %d,pan_max %d,tilt_min %d,tilt_max %d",
-               cnt->track.minx, cnt->track.maxx, cnt->track.miny, cnt->track.maxy);
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "For_SET_REL track_pan_Angel %d, track_tilt_Angel %d",
-               cnt->track.pan_angle, cnt->track.tilt_angle);
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "For_SET_REL move_X %d,move_Y %d", move_x_degrees, move_y_degrees);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("For_SET_REL pan_min %d,pan_max %d,tilt_min %d,tilt_max %d")
+        ,cnt->track.minx, cnt->track.maxx, cnt->track.miny, cnt->track.maxy);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("For_SET_REL track_pan_Angel %d, track_tilt_Angel %d")
+        ,cnt->track.pan_angle, cnt->track.tilt_angle);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("For_SET_REL move_X %d,move_Y %d"), move_x_degrees, move_y_degrees);
 
     /*
      * tilt up: - value
@@ -1188,11 +1245,13 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
         control_s.id = V4L2_CID_PAN_RELATIVE;
 
         control_s.value = pan.s16.pan;
-        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, " dev %d, addr= %d, control_S= %d, Wert= %d",
-                   dev, VIDIOC_S_CTRL, &control_s, pan.s16.pan);
+        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+            ,_(" dev %d, addr= %d, control_S= %d, Wert= %d")
+            ,dev, VIDIOC_S_CTRL, &control_s, pan.s16.pan);
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to move UVC camera!");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to move UVC camera!"));
             return 0;
         }
     }
@@ -1207,21 +1266,24 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
         control_s.id = V4L2_CID_TILT_RELATIVE;
 
         control_s.value = pan.s16.tilt;
-        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, " dev %d,addr= %d, control_S= %d, Wert= %d",
-                   dev, VIDIOC_S_CTRL, &control_s, pan.s16.tilt);
+        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+            ,_(" dev %d,addr= %d, control_S= %d, Wert= %d")
+            ,dev, VIDIOC_S_CTRL, &control_s, pan.s16.tilt);
 
         if (ioctl(dev, VIDIOC_S_CTRL, &control_s) < 0) {
-            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO, "Failed to move UVC camera!");
+            MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
+                ,_("Failed to move UVC camera!"));
             return 0;
         }
     }
 
-    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "Found MINMAX = %d",
-                cnt->track.minmaxfound);
+    MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+        ,_("Found MINMAX = %d"), cnt->track.minmaxfound);
 
     if (cnt->track.minmaxfound == 1) {
-        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "Before_REL_Y_Angel : x= %d , Y= %d",
-                   cnt->track.pan_angle, cnt->track.tilt_angle);
+        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+            ,_("Before_REL_Y_Angel : x= %d , Y= %d")
+            ,cnt->track.pan_angle, cnt->track.tilt_angle);
 
         if (move_x_degrees != 0)
             cnt->track.pan_angle += -pan.s16.pan / INCPANTILT;
@@ -1229,10 +1291,79 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
         if (move_y_degrees != 0)
             cnt->track.tilt_angle += -pan.s16.tilt / INCPANTILT;
 
-        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO, "After_REL_Y_Angel : x= %d , Y= %d",
-                   cnt->track.pan_angle, cnt->track.tilt_angle);
+        MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
+            ,_("After_REL_Y_Angel : x= %d , Y= %d")
+            ,cnt->track.pan_angle, cnt->track.tilt_angle);
     }
 
     return cnt->track.move_wait;
 }
 #endif /* HAVE_V4L2 */
+
+static unsigned int generic_move(struct context *cnt, enum track_action action, unsigned int manual,
+                                 int xoff, int yoff, struct coord *cent, struct images *imgs)
+{
+    char fmtcmd[PATH_MAX];
+    cnt->track_posx += cent->x;
+    cnt->track_posy += cent->y;
+
+    mystrftime(cnt, fmtcmd, sizeof(fmtcmd), cnt->track.generic_move, &cnt->current_image->timestamp_tv, NULL, 0);
+
+    if (!fork()) {
+        int i;
+        char buf[12];
+
+        /* Detach from parent */
+        setsid();
+
+        /* Provides data as environment variables */
+        if (manual)
+          setenv("TRACK_MANUAL", "manual", 1);
+        switch (action) {
+          case TRACK_CENTER:
+            setenv("TRACK_ACTION", "center", 1);
+            sprintf(buf, "%d", xoff);	setenv("TRACK_XOFF", buf, 1);
+            sprintf(buf, "%d", yoff);	setenv("TRACK_YOFF", buf, 1);
+            break;
+          case TRACK_MOVE:
+            setenv("TRACK_ACTION", "move", 1);
+            if (cent) {
+              sprintf(buf, "%d", cent->x);	setenv("TRACK_CENT_X", buf, 1);
+              sprintf(buf, "%d", cent->y);	setenv("TRACK_CENT_Y", buf, 1);
+              sprintf(buf, "%d", cent->width);	setenv("TRACK_CENT_WIDTH", buf, 1);
+              sprintf(buf, "%d", cent->height);	setenv("TRACK_CENT_HEIGHT", buf, 1);
+              sprintf(buf, "%d", cent->minx);	setenv("TRACK_CENT_MINX", buf, 1);
+              sprintf(buf, "%d", cent->maxx);	setenv("TRACK_CENT_MAXX", buf, 1);
+              sprintf(buf, "%d", cent->miny);	setenv("TRACK_CENT_MINY", buf, 1);
+              sprintf(buf, "%d", cent->maxy);	setenv("TRACK_CENT_MAXY", buf, 1);
+            }
+            if (imgs) {
+              sprintf(buf, "%d", imgs->width);	setenv("TRACK_IMGS_WIDTH", buf, 1);
+              sprintf(buf, "%d", imgs->height);	setenv("TRACK_IMGS_HEIGHT", buf, 1);
+              sprintf(buf, "%d", imgs->motionsize); setenv("TRACK_IMGS_MOTIONSIZE", buf, 1);
+            }
+        }
+
+        /*
+         * Close any file descriptor except console because we will
+         * like to see error messages
+         */
+        for (i = getdtablesize() - 1; i > 2; i--)
+            close(i);
+
+        execl("/bin/sh", "sh", "-c", fmtcmd, " &", NULL);
+
+        /* if above function succeeds the program never reach here */
+        MOTION_LOG(ALR, TYPE_EVENTS, SHOW_ERRNO
+            ,_("Unable to start external command '%s'")
+            ,cnt->track.generic_move);
+
+        exit(1);
+    }
+
+    MOTION_LOG(DBG, TYPE_EVENTS, NO_ERRNO
+        ,_("Executing external command '%s'")
+        , fmtcmd);
+
+    return cnt->track.move_wait;
+}
